# automatically generated file, don't edit



# Copyright 2011 David Cantrell, derived from data from libphonenumber
# http://code.google.com/p/libphonenumber/
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
package Number::Phone::StubCountry::SI;
use base qw(Number::Phone::StubCountry);

use strict;
use warnings;
use utf8;
our $VERSION = 1.20150718142141;

my $formatters = [{'leading_digits' => '[12]|3[4-8]|4[24-8]|5[2-8]|7[3-8]','pattern' => '(\\d)(\\d{3})(\\d{2})(\\d{2})'},{'pattern' => '([3-7]\\d)(\\d{3})(\\d{3})','leading_digits' => '[37][01]|4[0139]|51|6'},{'leading_digits' => '[89][09]','pattern' => '([89][09])(\\d{3,6})'},{'leading_digits' => '59|8[1-3]','pattern' => '([58]\\d{2})(\\d{5})'}];
my $validators = {'special_rate' => '(90\\d{4,6}|89[1-3]\\d{2,5})','geographic' => '(?:1\\d|[25][2-8]|3[4-8]|4[24-8]|7[3-8])\\d{6}','pager' => '','personal_number' => '','voip' => '(?:59|8[1-3])\\d{6}','toll_free' => '80\\d{4,6}','mobile' => '(?:[37][01]|4[0139]|51|6[48])\\d{6}','fixed_line' => '(?:1\\d|[25][2-8]|3[4-8]|4[24-8]|7[3-8])\\d{6}'};
sub new {
  my $class = shift;
  my $number = shift;
  $number =~ s/(^\+386|\D)//g;
  my $self = bless({ number => $number, formatters => $formatters, validators => $validators }, $class);
  return $self if ($self->is_valid());
  $number =~ s/(^0)//g;
  $self = bless({ number => $number, formatters => $formatters, validators => $validators }, $class);
  return $self->is_valid() ? $self : undef;
}

1;
